@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -24,8 +24,8 @@ class Horde_Support_Numerizer
     public static function factory($args = array())
     {
         $locale = isset($args['locale']) ? $args['locale'] : null;
-        if ($locale && strtolower($locale) != 'base') {
-            $locale = str_replace(' ', '_', ucwords(str_replace('_', ' ', strtolower($locale))));
+        if ($locale && Horde_String::lower($locale) != 'base') {
+            $locale = str_replace(' ', '_', Horde_String::ucwords(str_replace('_', ' ', Horde_String::lower($locale))));
             $class = 'Horde_Support_Numerizer_Locale_' . $locale;
             if (class_exists($class)) {
                 return new $class($args);
