@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @category   Horde
  * @package    Support
@@ -26,18 +26,12 @@ class Horde_Support_GuidTest extends PHPUnit_Framework_TestCase
     public function testDuplicates()
     {
         $values = array();
-        $cnt = 0;
 
         for ($i = 0; $i < 10000; ++$i) {
             $id = strval(new Horde_Support_Guid());
-            if (isset($values[$id])) {
-                $cnt++;
-            } else {
-                $values[$id] = 1;
-            }
+            $this->assertArrayNotHasKey($id, $values);
+            $values[$id] = 1;
         }
-
-        $this->assertEquals(0, $cnt);
     }
 
     public function testOptions()
